pySMHS
======

Smart House Control System
--------------------------

- ``Website:`` http://www.pysmhs.org

- ``Source:`` https://github.com/aborilov/pysmhs

- ``Documentation:`` http://docs.pysmhs.org

License: MIT License


Features
--------

* Simple, small and extensible. It's easy to write your own handlers,
  actions.
* Configured in Python.

Current Release
---------------

The current alpha version of pysmhs

Community
---------

only two of us

Bug Tracker
-----------

Please report any suggestions, feature requests, bug reports, or annoyances to
the Github 
